diff artifacts/src/main/java/org/dive4elements/river/utils/ArtifactMapfileGenerator.java @ 5867:59ff03ff48f1

River artifacts: Renamed FLYSArtifact(Collection) to D4EArtifact(Collection).
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 28 Apr 2013 15:23:01 +0200
parents 73da40528cf2
children af13ceeba52a
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/utils/ArtifactMapfileGenerator.java	Sun Apr 28 15:14:30 2013 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/utils/ArtifactMapfileGenerator.java	Sun Apr 28 15:23:01 2013 +0200
@@ -9,7 +9,7 @@
 package org.dive4elements.river.utils;
 
 import org.dive4elements.artifacts.CallContext;
-import org.dive4elements.river.artifacts.FLYSArtifact;
+import org.dive4elements.river.artifacts.D4EArtifact;
 import org.dive4elements.river.artifacts.access.RiverAccess;
 import org.dive4elements.river.artifacts.model.LayerInfo;
 import org.dive4elements.river.artifacts.model.map.WMSDBLayerFacet;
@@ -65,11 +65,11 @@
      * Creates a layer file used for Mapserver's mapfile which represents the
      * floodmap.
      *
      * @param flys The FLYSArtifact that owns <i>wms</i>.
      * @param wms The WMSLayerFacet that contains information for the layer.
      */
     public void createUeskLayer(
-        FLYSArtifact  flys,
+        D4EArtifact  flys,
         WSPLGENLayerFacet wms,
         String        style,
         CallContext context
@@ -113,10 +113,10 @@
      * Creates a layer file used for Mapserver's mapfile which represents the
      * user defined barriers.
      *
      * @param flys The FLYSArtifact that owns <i>wms</i>.
      * @param wms The WMSLayerFacet that contains information for the layer.
      */
-    public void createBarriersLayer(FLYSArtifact flys, WMSLayerFacet wms)
+    public void createBarriersLayer(D4EArtifact flys, WMSLayerFacet wms)
     throws FileNotFoundException, IOException
     {
         logger.debug("createBarriersLayer");
@@ -130,7 +130,7 @@
 
 
     protected void createBarriersLineLayer(
-        FLYSArtifact  flys,
+        D4EArtifact  flys,
         WMSLayerFacet wms
     )
     throws FileNotFoundException, IOException
@@ -175,7 +175,7 @@
     }
 
     protected void createBarriersPolygonLayer(
-            FLYSArtifact  flys,
+            D4EArtifact  flys,
             WMSLayerFacet wms
         )
         throws FileNotFoundException, IOException
@@ -224,10 +224,10 @@
          * Creates a layer file used for Mapserver's mapfile which represents the
          * shape files uploaded by the user.
          *
          * @param flys The FLYSArtifact that owns <i>wms</i>.
          * @param wms The WMSLayerFacet that contains information for the layer.
          */
-        public void createUserShapeLayer(FLYSArtifact flys, WMSLayerFacet wms)
+        public void createUserShapeLayer(D4EArtifact flys, WMSLayerFacet wms)
         throws FileNotFoundException, IOException
         {
             logger.debug("createUserShapeLayer");
@@ -290,11 +290,11 @@
          * Creates a layer file used for Mapserver's mapfile which represents
          * geometries from database.
          *
          * @param flys The FLYSArtifact that owns <i>wms</i>.
          * @param wms The WMSLayerFacet that contains information for the layer.
          */
         public void createDatabaseLayer(
-            FLYSArtifact    flys,
+            D4EArtifact    flys,
             WMSDBLayerFacet wms,
             String          style
         )
@@ -65,11 +65,11 @@
      * floodmap.
      *
-     * @param flys The FLYSArtifact that owns <i>wms</i>.
+     * @param flys The D4EArtifact that owns <i>wms</i>.
      * @param wms The WMSLayerFacet that contains information for the layer.
      */
@@ -113,10 +113,10 @@
      * user defined barriers.
      *
-     * @param flys The FLYSArtifact that owns <i>wms</i>.
+     * @param flys The D4EArtifact that owns <i>wms</i>.
      * @param wms The WMSLayerFacet that contains information for the layer.
      */
@@ -224,10 +224,10 @@
          * shape files uploaded by the user.
          *
-         * @param flys The FLYSArtifact that owns <i>wms</i>.
+         * @param flys The D4EArtifact that owns <i>wms</i>.
          * @param wms The WMSLayerFacet that contains information for the layer.
          */
@@ -290,11 +290,11 @@
          * geometries from database.
          *
-         * @param flys The FLYSArtifact that owns <i>wms</i>.
+         * @param flys The D4EArtifact that owns <i>wms</i>.
          * @param wms The WMSLayerFacet that contains information for the layer.
          */

http://dive4elements.wald.intevation.org